# moldenViz

[![PyPI - Version](https://img.shields.io/pypi/v/moldenviz.svg)](https://pypi.org/project/moldenviz)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/moldenviz.svg)](https://pypi.org/project/moldenviz)

-----

## Table of Contents

- [Installation](#installation)

## Installation

```console
pip install moldenViz
```

## Roadmap
- [x] 0.1: Basic commands inside python.
- [ ] 0.2: GUI integration.
- [ ] 0.3: CLI options.
